Discover Packages
github.com/u16-io/FindSenryu4Discord
db
package
Version:
v0.0.0-...-72a9452
Opens a new window with list of versions in this module.
Published: Apr 12, 2026
License: MIT
Opens a new window with license information.
Imports: 17
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Close closes the database connection
GetDB returns the database instance
Init initializes the database connection
IsConnected returns true if database is connected
Migrate runs all schema and data migrations using golang-migrate.
SQL migration files are embedded per dialect (sqlite3/postgres).
It must be called after Init().
type Stats struct {
SenryuCount int64
MutedChannelCount int64
OptOutCount int64
IsConnected bool
}
Stats returns database statistics
GetStats returns database statistics
Source Files
¶
Click to show internal directories.
Click to hide internal directories.